;; Generated package description from embark.el  -*- no-byte-compile: t -*-
(define-package "embark" "1.0.0.20240327.80802" "Conveniently act on minibuffer completions" '((emacs "27.1") (compat "29.1.4.0")) :commit "d3c9d1b4c890cf365846cc2b418f37341999e79f" :authors '(("Omar Antolín Camarena" . "omar@matem.unam.mx")) :maintainer '("Omar Antolín Camarena" . "omar@matem.unam.mx") :keywords '("convenience") :url "https://github.com/oantolin/embark")
